Learn R Programming

BayesCACE (version 1.2.3)

epidural_ic: Meta-analysis data without full compliance information

Description

The data contains a meta analysis of the association between using epidural analgesia in labor and the risk of cesarean section. It contains 27 studies, only 10 out of which have full compliance information.

Usage

data(epidural_ic)

Arguments

Format

An object of class data.frame with 27 rows and 14 columns.

References

bannister-tyrrell2015dataBayesCACE

Examples

Run this code
data(epidural_ic)

Run the code above in your browser using DataLab