coda.names: Get names of node array
Description
This is a helper function from the rjags library in order to get the names of the individual elements
of a node array. See the package rjags for more details.
Usage
coda.names(basename, dim)
Value
It returns a list of the names of individual elements
Arguments
- basename
the node names
- dim
dimension of the nodes
References
plummer2021rjagsBayesCACE